summaryrefslogtreecommitdiffstats
path: root/konversation/src/nicksonlineitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/nicksonlineitem.h')
-rw-r--r--konversation/src/nicksonlineitem.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/konversation/src/nicksonlineitem.h b/konversation/src/nicksonlineitem.h
index 5711e60..e7e911d 100644
--- a/konversation/src/nicksonlineitem.h
+++ b/konversation/src/nicksonlineitem.h
@@ -27,23 +27,23 @@ class NicksOnlineItem : public KListViewItem
};
NicksOnlineItem(int type,
- QListView* parent,
- const QString& name,
- const QString& col2 = QString());
+ TQListView* parent,
+ const TQString& name,
+ const TQString& col2 = TQString());
NicksOnlineItem(int type,
- QListViewItem* parent,
- const QString& name,
- const QString& col2 = QString());
+ TQListViewItem* parent,
+ const TQString& name,
+ const TQString& col2 = TQString());
/**
* Reimplemented to make sure, "Offline" items always get sorted to the bottom of the list
* @param i Pointer to the QListViewItem to compare with.
* @param col The column to compare
* @param ascending Specify sorting direction
* @return -1 if this item's value is smaller than i, 0 if they are equal, 1 if it's greater
*/
- virtual int compare(QListViewItem* i,int col,bool ascending) const;
+ virtual int compare(TQListViewItem* i,int col,bool ascending) const;
/**
* Returns the type of the item.
@@ -27,23 +27,23 @@ class NicksOnlineItem : public KListViewItem
/**
* Reimplemented to make sure, "Offline" items always get sorted to the bottom of the list
- * @param i Pointer to the QListViewItem to compare with.
+ * @param i Pointer to the TQListViewItem to compare with.
* @param col The column to compare
* @param ascending Specify sorting direction